[![codecov](https://codecov.io/gh/laminlabs/lamindb/branch/main/graph/badge.svg?token=VKMRJ7OWR3)](https://codecov.io/gh/laminlabs/lamindb)
[![pypi](https://img.shields.io/pypi/v/lamindb?color=%2334D058&label=pypi%20package)](https://pypi.org/project/lamindb)

# LaminDB: Manage data & analyses

Read the [docs](https://lamin.ai/docs/lamindb).
